4.43. umbra.ui.inputAccelerators — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.43. umbra.ui.inputAccelerators

inputAccelerators.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the Application input accelerators objects.

Others:

## 4.43.1. Module Attributes

`umbra.ui.inputAccelerators.` `LOGGER`

## 4.43.2. Functions

`umbra.ui.inputAccelerators.` `getEditorCapability`(editor, capability)

  This definition returns given editor capability.

  Parameters: | editor – Document editor. ( QWidget ) capability – Capability to retrieve. ( String )
  Returns: | Capability. ( Object )

`umbra.ui.inputAccelerators.` `indentationPreEventInputAccelerators`(editor, event)

  This definition implements indentation pre event input accelerators.

  Parameters: | editor – Document editor. ( QWidget ) event – Event being handled. ( QEvent )
  Returns: | Process event. ( Boolean )

`umbra.ui.inputAccelerators.` `indentationPostEventInputAccelerators`(editor, event)

  This definition implements indentation post event input accelerators.

  Parameters: | editor – Document editor. ( QWidget ) event – Event being handled. ( QEvent )
  Returns: | Method success. ( Boolean )

`umbra.ui.inputAccelerators.` `performCompletion`(editor)

  This definition performs the completion on given editor.

  Parameters: | editor – Document editor. ( QWidget )
  Returns: | Method success. ( Boolean )

`umbra.ui.inputAccelerators.` `completionPreEventInputAccelerators`(editor, event)

  This definition implements completion pre event input accelerators.

  Parameters: | editor – Document editor. ( QWidget ) event – Event being handled. ( QEvent )
  Returns: | Process event. ( Boolean )

`umbra.ui.inputAccelerators.` `completionPostEventInputAccelerators`(editor, event)

  This definition implements completion post event input accelerators.

  Parameters: | editor – Document editor. ( QWidget ) event – Event being handled. ( QEvent )
  Returns: | Process event. ( Boolean )

`umbra.ui.inputAccelerators.` `symbolsExpandingPreEventInputAccelerators`(editor, event)

  This definition implements symbols expanding pre event input accelerators.

  Parameters: | editor – Document editor. ( QWidget ) event – Event being handled. ( QEvent )
  Returns: | Process event. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »